![PsiZ logo](docs/img/full_logo_300.png)

# PsiZ Datasets

---
**WARNING:** This package is pre-release and the API is not stable. All APIs are subject to change and all releases are alpha.

---

## Purpose
Provide pre-formatted TensorFlow Datasets for easy consumption by models.

## Resources
* Official Psiz Documentation: [psiz.readthedocs.io/en/latest](https://psiz.readthedocs.io/en/latest/)

## Installation
There are two different ways to install: PyPI or git.

### Using PyPI
```
$ pip install psiz-datasets
```

### Using git
```
# Clone the repository from GitHub to your local machine.
$ git clone https://github.com/psiz-org/psiz-datasets.git
# Use `pip` to install the cloned repository.
$ pip install /local/path/to/psiz-datasets
```

## Contribution Guidelines
If you would like to contribute please see the [contributing guidelines](CONTRIBUTING.md).

This project uses a [Code of Conduct](CODE.md) adapted from the [Contributor Covenant](https://www.contributor-covenant.org/)
version 2.0, available at <https://www.contributor-covenant.org/version/2/0/code_of_conduct.html>.

## Licence
This project is licensed under the Apache Licence 2.0 - see LICENSE file for details.
